@@ -164,7 +164,7 @@ class MapListView(ManualListView):
 			value = row[field['index']]
 			if value is None:
 				return ''
-			if isinstance(value, float) and not math.isnan(value):
+			if isinstance(value, (int, float)) and not math.isnan(value):
 				return times.format_time(int(value))
 			return 'None'
 
@@ -172,7 +172,7 @@ class MapListView(ManualListView):
 			value = row[field['index']]
 			if value is None:
 				return ''
-			if isinstance(value, float) and not math.isnan(value):
+			if isinstance(value, (int, float)) and not math.isnan(value):
 				return int(value)
 			return 'None'
 
@@ -180,14 +180,13 @@ class MapListView(ManualListView):
 			value = row[field['index']]
 			if value is None:
 				return ''
-			prefix = ''
-			if value > 0.0:
-				prefix = '$6CF'
-			elif value < 0.0:
-				prefix = '$F66'
-
-			return '{}{}'.format(prefix, value)
-
+			if isinstance(value, (int, float)) and not math.isnan(value):
+				if value > 0.0:
+					prefix = '$6CF'
+				elif value < 0.0:
+					prefix = '$F66'
+				return '{}{}'.format(prefix, float(value))
+			
 		if self.advanced and not self.app.instance.performance_mode:
 			if 'karma' in self.app.instance.apps.apps:
 				fields.append({
@@ -754,4 +753,4 @@ class AddToFolderView(TemplateView):
 			return
 
 		self.response_future.set_result(True)
-		self.response_future.done()
+		self.response_future.done()
\ No newline at end of file
